@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.9997';
+our $VERSION = '0.9998';
 
 BEGIN {
     # We tell the Oracle connector which encoding to use. The last part of the
@@ -42,11 +42,14 @@ sub destination {
         || ( $^O eq 'MSWin32' ? $ENV{LOCAL} : undef )
         || $ENV{ORACLE_SID}
         || $self->username
-        || $self->sqitch->sysuser
     );
     return $uri->as_string;
 }
 
+# No username or password defaults.
+sub _def_user { }
+sub _def_pass { }
+
 has _sqlplus => (
     is         => 'ro',
     isa        => ArrayRef,
@@ -109,7 +112,7 @@ has dbh => (
                     if (my $schema = $self->registry) {
                         try {
                             $dbh->do("ALTER SESSION SET CURRENT_SCHEMA = $schema");
-                            # http://www.nntp.perl.org/group/perl.dbi.dev/2013/11/msg7622.html
+                            # https://www.nntp.perl.org/group/perl.dbi.dev/2013/11/msg7622.html
                             $dbh->set_err(undef, undef) if $dbh->err;
                         };
                     }
@@ -136,7 +139,7 @@ sub _log_conflicts_param {
 }
 
 sub _ts2char_format {
-    q{CAST(to_char(%1$s AT TIME ZONE 'UTC', '"year":YYYY:"month":MM:"day":DD') || to_char(%1$s AT TIME ZONE 'UTC', ':"hour":HH24:"minute":MI:"second":SS:"time_zone":"UTC"')  AS VARCHAR2(92 char))}
+    q{CAST(to_char(%1$s AT TIME ZONE 'UTC', '"year":YYYY:"month":MM:"day":DD') AS VARCHAR2(100 byte)) || CAST(to_char(%1$s AT TIME ZONE 'UTC', ':"hour":HH24:"minute":MI:"second":SS:"time_zone":"UTC"')  AS VARCHAR2(168 byte))}
 }
 
 sub _ts_default { 'current_timestamp' }
@@ -149,7 +152,7 @@ sub _char2ts {
 }
 
 sub _listagg_format {
-    # http://stackoverflow.com/q/16313631/79202
+    # https://stackoverflow.com/q/16313631/79202
     return q{CAST(COLLECT(CAST(%s AS VARCHAR2(512))) AS sqitch_array)};
 }
 
@@ -431,7 +434,7 @@ sub _registry_variable {
     my $schema = $self->registry;
     return $schema ? ("DEFINE registry=$schema") : (
         # Select the current schema into &registry.
-        # http://www.orafaq.com/node/515
+        # https://www.orafaq.com/node/515
         'COLUMN sname for a30 new_value registry',
         q{SELECT SYS_CONTEXT('USERENV', 'SESSION_SCHEMA') AS sname FROM DUAL;},
     );
@@ -668,11 +671,6 @@ sub log_revert_change {
     return $self->_log_event( revert => $change, $del_tags, $req, $conf );
 }
 
-sub _ts2char($) {
-    my $col = shift;
-    return qq{to_char($col AT TIME ZONE 'UTC', 'YYYY:MM:DD:HH24:MI:SS')};
-}
-
 sub _no_table_error  {
     return $DBI::err && $DBI::err == 942; # ORA-00942: table or view does not exist
 }
