@@ -18,7 +18,7 @@ use Moo;
 use App::Sqitch::Types qw(Str Int HashRef ChangeList LineList Maybe Sqitch URI File Target);
 use constant SYNTAX_VERSION => '1.0.0';
 
-our $VERSION = '0.9997';
+our $VERSION = '0.9998';
 
 # Like [:punct:], but excluding _. Copied from perlrecharclass.
 my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
@@ -410,7 +410,7 @@ sub _parse {
 
             # Got dependencies?
             if (my $deps = $params{dependencies}) {
-                my (@req, @con);
+                my (@req, @con, %seen_dep);
                 for my $depstring (split /[[:blank:]]+/, $deps) {
                     my $dep_params = App::Sqitch::Plan::Depend->parse(
                         $depstring,
@@ -422,6 +422,10 @@ sub _parse {
                         plan => $self,
                         %{ $dep_params },
                     );
+                    # Prevent dupes.
+                    $raise_syntax_error->(
+                        __x( 'Duplicate dependency "{dep}"', dep => $depstring ),
+                    ) if $seen_dep{$depstring}++;
                     if ($dep->conflicts) {
                         push @con => $dep;
                     } else {
